@@ -1,8 +1,7 @@
 from orwynn.app.ErrorHandler import ErrorHandler
-from orwynn.log.Log import Log
 from orwynn.proxy.BootProxy import BootProxy
-from orwynn.util.validation import RequestValidationException
-from orwynn.util.web import JSONResponse, Request, Response
+from orwynn.validation import RequestValidationException
+from orwynn.web import JSONResponse, Request, Response
 
 
 class DefaultRequestValidationExceptionHandler(ErrorHandler):
@@ -13,7 +12,6 @@ class DefaultRequestValidationExceptionHandler(ErrorHandler):
         request: Request,
         error: RequestValidationException
     ) -> Response:
-        Log.error(repr(error))
         return JSONResponse(
             BootProxy.ie().api_indication.digest(error),
             422
