@@ -1,5 +1,6 @@
-from orwynn.di.collecting.provider_dependencies_map import \
-    ProviderDependenciesMap
+from orwynn.di.collecting.provider_dependencies_map import (
+    ProviderDependenciesMap,
+)
 from orwynn.di.DIContainer import DIContainer
 from orwynn.di.init.init_providers import init_providers
 from tests.std.Assertion import Assertion
