@@ -1,9 +1,9 @@
+from orwynn import validation
 from orwynn.boot.BootMode import BootMode
 from orwynn.log.Log import Log
 from orwynn.log.LogConfig import LogConfig
 from orwynn.log.LogHandler import LogHandler
 from orwynn.proxy.BootProxy import BootProxy
-from orwynn.util import validation
 
 
 def configure_log(config: LogConfig) -> None:
