@@ -6,7 +6,7 @@ from orwynn.controller.http.HTTPController import HTTPController
 from orwynn.middleware.Middleware import Middleware
 from orwynn.module.Module import Module
 from orwynn.test.Client import Client
-from orwynn.util.web import Request, Response, TestResponse
+from orwynn.web import Request, Response, TestResponse
 
 
 def test_basic():
